@@ -25,12 +25,12 @@ class EtsyAuth:
     __base_endpoint:str = "https://openapi.etsy.com/v3/application/"
     
     
-    def __post__init__(self):
+    def __post_init__(self):
         user_info_endpoint = "oauth/userinfo"
         
         response = self.request("GET", user_info_endpoint)
         
-        self.user_info = OtherUser(**response)
+        setattr(self, "user_info", OtherUser(**response))
         
         
     def request(self, endpoint: str, method="GET", *args, **kwargs) -> dict:
